The MPL Reference Manual: Arithmetic Operations

Prev Next | Back Along | Up Home | Full TOC | Front Page / Metafunctions / Arithmetic Operations

# Arithmetic Operations

- plus
- minus
- times
- divides
- modulus
- negate

Prev Next | Back Along | Up Home | Full TOC | Copyright © 2001-2009 Aleksey Gurtovoy and David Abrahams Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)